@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -346,7 +346,6 @@ public class TimeZoneNames_ia extends TimeZoneNamesBundle {
             { "PST8PDT", America_Pacific },
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Omsk", Omsk },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Chita", Yakutsk },
             { "Africa/Lome", GMT },
             { "Asia/Beirut", Europe_Eastern },
@@ -380,7 +379,6 @@ public class TimeZoneNames_ia extends TimeZoneNamesBundle {
             { "America/Aruba", Atlantic },
             { "America/Boise", America_Mountain },
             { "America/Thule", Atlantic },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Ust-Nera", Vladivostok },
@@ -426,7 +424,6 @@ public class TimeZoneNames_ia extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Mountain },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
             { "America/Juneau", Alaska },
@@ -541,7 +538,6 @@ public class TimeZoneNames_ia extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
@@ -643,12 +639,15 @@ public class TimeZoneNames_ia extends TimeZoneNamesBundle {
             { "timezone.excity.America/Nassau", "Nassau" },
             { "timezone.excity.America/Panama", "Panama" },
             { "timezone.excity.America/Regina", "Regina" },
+            { "timezone.excity.Asia/Hong_Kong", "Hongkong" },
             { "timezone.excity.Asia/Kamchatka", "Kamchatka" },
             { "timezone.excity.Europe/Andorra", "Andorra" },
             { "timezone.excity.Europe/Saratov", "Saratov" },
             { "timezone.excity.Europe/Tallinn", "Tallinn" },
             { "timezone.excity.Europe/Vatican", "Vaticano" },
             { "timezone.excity.Europe/Vilnius", "Vilnius" },
+            { "timezone.excity.Indian/Mayotte", "Mayotta" },
+            { "timezone.excity.Africa/Djibouti", "Djibuti" },
             { "timezone.excity.America/Antigua", "Antigua" },
             { "timezone.excity.America/Chicago", "Chicago" },
             { "timezone.excity.America/Creston", "Creston" },
@@ -680,6 +679,7 @@ public class TimeZoneNames_ia extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Helsinki", "Helsinki" },
             { "timezone.excity.Europe/Sarajevo", "Sarajevo" },
             { "timezone.excity.Europe/Uzhgorod", "Uzhgorod" },
+            { "timezone.excity.Indian/Maldives", "Maldivas" },
             { "timezone.excity.America/Anguilla", "Anguilla" },
             { "timezone.excity.America/Barbados", "Barbados" },
             { "timezone.excity.America/Dominica", "Dominica" },
@@ -707,6 +707,7 @@ public class TimeZoneNames_ia extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Stockholm", "Stockholm" },
             { "timezone.excity.Europe/Ulyanovsk", "Ulyanovsk" },
             { "timezone.excity.Europe/Volgograd", "Volgograd" },
+            { "timezone.excity.Indian/Mauritius", "Mauritio" },
             { "timezone.excity.America/Anchorage", "Anchorage" },
             { "timezone.excity.America/Chihuahua", "Chihuahua" },
             { "timezone.excity.America/Glace_Bay", "Glace Bay" },
@@ -751,6 +752,7 @@ public class TimeZoneNames_ia extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thunder_Bay", "Thunder Bay" },
             { "timezone.excity.America/Yellowknife", "Yellowknife" },
             { "timezone.excity.Arctic/Longyearbyen", "Longyearbyen" },
+            { "timezone.excity.Atlantic/Cape_Verde", "Capo Verde" },
             { "timezone.excity.America/Blanc-Sablon", "Blanc-Sablon" },
             { "timezone.excity.America/Danmarkshavn", "Danmarkshavn" },
             { "timezone.excity.America/Dawson_Creek", "Dawson Creek" },
